Author: kevlo
Date: Fri Dec 25 14:51:36 2015
New Revision: 292730
URL: https://svnweb.freebsd.org/changeset/base/292730

Log:
  Fix typo (s/harware/hardware/)

Modified:
  head/sys/arm/arm/pmap-v6-new.c
  head/sys/dev/isci/scil/scic_sds_phy.h
  head/sys/dev/netmap/netmap.c
  head/sys/mips/cavium/cvmx_config.h
  head/sys/netinet/if_ether.c

Modified: head/sys/arm/arm/pmap-v6-new.c
==============================================================================
--- head/sys/arm/arm/pmap-v6-new.c      Fri Dec 25 14:27:37 2015        
(r292729)
+++ head/sys/arm/arm/pmap-v6-new.c      Fri Dec 25 14:51:36 2015        
(r292730)
@@ -3194,7 +3194,7 @@ setpte1:
                 * When page is not modified, PTE2_RO can be set without
                 * a TLB invalidation.
                 *
-                * Note: When modified bit is being set, then in harware case,
+                * Note: When modified bit is being set, then in hardware case,
                 *       the TLB entry is re-read (updated) from PT2, and in
                 *       software case (abort), the PTE2 is read from PT2 and
                 *       TLB flushed if changed. The following cmpset() solves
@@ -6170,7 +6170,7 @@ pte1_seta:
        /*
         * Handle modify bits for page and section. Note that the modify
         * bit is emulated by software. So PTEx_RO is software read only
-        * bit and PTEx_NM flag is real harware read only bit.
+        * bit and PTEx_NM flag is real hardware read only bit.
         *
         * QQQ: This is hardware emulation, we do not call userret()
         *      for aborts from user mode.

Modified: head/sys/dev/isci/scil/scic_sds_phy.h
==============================================================================
--- head/sys/dev/isci/scil/scic_sds_phy.h       Fri Dec 25 14:27:37 2015        
(r292729)
+++ head/sys/dev/isci/scil/scic_sds_phy.h       Fri Dec 25 14:51:36 2015        
(r292730)
@@ -201,7 +201,7 @@ enum SCIC_SDS_PHY_PROTOCOL
  * @struct SCIC_SDS_PHY
  *
  * @brief This structure  contains or references all of the data necessary to
- *        represent the core phy object and SCU harware protocol engine.
+ *        represent the core phy object and SCU hardware protocol engine.
  */
 typedef struct SCIC_SDS_PHY
 {

Modified: head/sys/dev/netmap/netmap.c
==============================================================================
--- head/sys/dev/netmap/netmap.c        Fri Dec 25 14:27:37 2015        
(r292729)
+++ head/sys/dev/netmap/netmap.c        Fri Dec 25 14:51:36 2015        
(r292730)
@@ -589,7 +589,7 @@ netmap_set_all_rings(struct netmap_adapt
 /*
  * Convenience function used in drivers.  Waits for current txsync()s/rxsync()s
  * to finish and prevents any new one from starting.  Call this before turning
- * netmap mode off, or before removing the harware rings (e.g., on module
+ * netmap mode off, or before removing the hardware rings (e.g., on module
  * onload).  As a rule of thumb for linux drivers, this should be placed near
  * each napi_disable().
  */

Modified: head/sys/mips/cavium/cvmx_config.h
==============================================================================
--- head/sys/mips/cavium/cvmx_config.h  Fri Dec 25 14:27:37 2015        
(r292729)
+++ head/sys/mips/cavium/cvmx_config.h  Fri Dec 25 14:51:36 2015        
(r292730)
@@ -63,7 +63,7 @@
 #define CVMX_ENABLE_PKO_FUNCTIONS
 
 /* Define to enable the use of simple executive helper functions. These
-** include many harware setup functions.  See cvmx-helper.[ch] for
+** include many hardware setup functions.  See cvmx-helper.[ch] for
 ** details.
 */
 #define CVMX_ENABLE_HELPER_FUNCTIONS

Modified: head/sys/netinet/if_ether.c
==============================================================================
--- head/sys/netinet/if_ether.c Fri Dec 25 14:27:37 2015        (r292729)
+++ head/sys/netinet/if_ether.c Fri Dec 25 14:51:36 2015        (r292730)
@@ -599,7 +599,7 @@ arpintr(struct mbuf *m)
                layer = "firewire";
 
                /*
                 * Restrict too long harware addresses.
                 * Currently we are capable of handling 20-byte
                 * addresses ( sizeof(lle->ll_addr) )
                 */
@@ -608,8 +608,8 @@ arpintr(struct mbuf *m)
                break;
        default:
                ARP_LOG(LOG_NOTICE,
-                   "packet with unknown harware format 0x%02d received on 
%s\n",
-                   ntohs(ar->ar_hrd), if_name(ifp));
+                   "packet with unknown hardware format 0x%02d received on "
+                   "%s\n", ntohs(ar->ar_hrd), if_name(ifp));
                m_freem(m);
                return;
        }
@@ -599,7 +599,7 @@ arpintr(struct mbuf *m)
 
                /*
-                * Restrict too long harware addresses.
+                * Restrict too long hardware addresses.
                 * Currently we are capable of handling 20-byte
                 * addresses ( sizeof(lle->ll_addr) )
_______________________________________________
[email protected] mailing list
https://lists.freebsd.org/mailman/listinfo/svn-src-head
To unsubscribe, send any mail to "[email protected]"

Reply via email to